==> zio-aws-iot_2.12-5.17.191.2-sources.jar: zio/aws/iot/model/ListDetectMitigationActionsTasksResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListDetectMitigationActionsTasksResponse(
    tasks: Optional[
      Iterable[zio.aws.iot.model.DetectMitigationActionsTaskSummary]
    ] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.ListDetectMitigationActionsTasksResponse = {
    import ListDetectMitigationActionsTasksResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.ListDetectMitigationActionsTasksResponse
      .builder()
      .optionallyWith(
        tasks.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tasks)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.iot.model.ListDetectMitigationActionsTasksResponse.ReadOnly =
    zio.aws.iot.model.ListDetectMitigationActionsTasksResponse
      .wrap(buildAwsValue())
}
object ListDetectMitigationActionsTasksResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.ListDetectMitigationActionsTasksResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.ListDetectMitigationActionsTasksResponse =
      zio.aws.iot.model.ListDetectMitigationActionsTasksResponse(
        tasks.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def tasks: Optional[
      List[zio.aws.iot.model.DetectMitigationActionsTaskSummary.ReadOnly]
    ]
    def nextToken: Optional[NextToken]
    def getTasks: ZIO[Any, AwsError, List[
      zio.aws.iot.model.DetectMitigationActionsTaskSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("tasks", tasks)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.ListDetectMitigationActionsTasksResponse
  ) extends zio.aws.iot.model.ListDetectMitigationActionsTasksResponse.ReadOnly {
    override val tasks: Optional[
      List[zio.aws.iot.model.DetectMitigationActionsTaskSummary.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.tasks())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.iot.model.DetectMitigationActionsTaskSummary.wrap(item)
        }.toList
      )
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.iot.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.ListDetectMitigationActionsTasksResponse
  ): zio.aws.iot.model.ListDetectMitigationActionsTasksResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iot_3-5.17.104.11-sources.jar: zio/aws/iot/model/ListDetectMitigationActionsTasksResponse.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.NextToken
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ListDetectMitigationActionsTasksResponse(
    tasks: Option[
      Iterable[zio.aws.iot.model.DetectMitigationActionsTaskSummary]
    ] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.ListDetectMitigationActionsTasksResponse = {
    import ListDetectMitigationActionsTasksResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.ListDetectMitigationActionsTasksResponse
      .builder()
      .optionallyWith(
        tasks.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tasks)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.iot.model.ListDetectMitigationActionsTasksResponse.ReadOnly =
    zio.aws.iot.model.ListDetectMitigationActionsTasksResponse
      .wrap(buildAwsValue())
}
object ListDetectMitigationActionsTasksResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.ListDetectMitigationActionsTasksResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.ListDetectMitigationActionsTasksResponse =
      zio.aws.iot.model.ListDetectMitigationActionsTasksResponse(
        tasks.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def tasks: Option[
      List[zio.aws.iot.model.DetectMitigationActionsTaskSummary.ReadOnly]
    ]
    def nextToken: Option[NextToken]
    def getTasks: ZIO[Any, AwsError, List[
      zio.aws.iot.model.DetectMitigationActionsTaskSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("tasks", tasks)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.ListDetectMitigationActionsTasksResponse
  ) extends zio.aws.iot.model.ListDetectMitigationActionsTasksResponse.ReadOnly {
    override val tasks: Option[
      List[zio.aws.iot.model.DetectMitigationActionsTaskSummary.ReadOnly]
    ] = scala
      .Option(impl.tasks())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.iot.model.DetectMitigationActionsTaskSummary.wrap(item)
        }.toList
      )
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.iot.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.ListDetectMitigationActionsTasksResponse
  ): zio.aws.iot.model.ListDetectMitigationActionsTasksResponse.ReadOnly =
    new Wrapper(impl)
}
